new_with_values_single

Function new_with_values_single 

fn new_with_values_single<F: Field, S, T>(
    product: &Product<F, S>,
    values: Vec<T>,
) -> Product<F, T>
Helper for new_with_values. Set the values of the Product to the given values, panicking if the lengths do not match.