pub struct Product<F: Field, T> {
pub intermediates: Vec<Intermediate<F, T>>,
pub coefficient: F,
}Expand description
Represents a fully bound product of MLEs, or a single MLE (which we consider a simple product). Data structure for extracting the values to be commited to, their “mxi” values (i.e. their public coefficients), and also the claims made on other layers.
Fields
intermediates: Vec<Intermediate<F, T>>the evaluated MLEs that are being multiplied and their intermediates in the order a, b, ab, c, abc, d, abcd, …
coefficient: Fthe (public) coefficient i.e. the “mxi”
Implementations
Sourceimpl<F: Field> Product<F, Option<F>>
impl<F: Field> Product<F, Option<F>>
Sourcepub fn new(mles: &[MleDescription<F>], coefficient: F, bindings: &[F]) -> Self
pub fn new(mles: &[MleDescription<F>], coefficient: F, bindings: &[F]) -> Self
Creates a new Product from a vector of MleDescription<F>.
Sourcepub fn new_from_mul_gate(
mles: &[MleDescription<F>],
coefficient: F,
bindings: &[&[F]],
) -> Self
pub fn new_from_mul_gate( mles: &[MleDescription<F>], coefficient: F, bindings: &[&[F]], ) -> Self
Creates a new Product from a vector of MleDescription<F>.
fn build_atom( mle: &MleDescription<F>, bindings: &[F], ) -> Intermediate<F, Option<F>>
Sourceimpl<F: Field> Product<F, F>
impl<F: Field> Product<F, F>
Sourcepub fn new(mles: &[DenseMle<F>], coefficient: F) -> Self
pub fn new(mles: &[DenseMle<F>], coefficient: F) -> Self
Creates a new Product from a vector of fully bound MleRefs. Panics if any are not fully bound.
fn build_atom(mle: &DenseMle<F>) -> Intermediate<F, F>
Sourceimpl<F: Field, T: Clone> Product<F, T>
impl<F: Field, T: Clone> Product<F, T>
Sourcepub fn get_result(&self) -> T
pub fn get_result(&self) -> T
Return the resulting value of the product. Useful to build the commitment to the oracle evaluation.
Sourcepub fn get_product_triples(&self) -> Option<Vec<(T, T, T)>>
pub fn get_product_triples(&self) -> Option<Vec<(T, T, T)>>
Return a vector of triples (x, y, z) where z=x*y, or None.